// Example Script that demonstrates how to capture spectral data
//

#include "stdafx.h"
#include "WSAInterface.h"

int _tmain(int argc, _TCHAR* argv[])
{
	// The device instance
	int64_t wsaHandle;

	// Device settings
	char ip[20] = "10.126.110.123";
	uint64_t fstart = 2400000000;
	uint64_t fstop = 2600000000;
	uint32_t rbw = 100000;
	char mode[20] = "SH";
	int32_t attenuator = 30;
	
	// The size of the expected spectral data
	uint32_t sweep_size;

	// Array to hold the spectral data
	float *spectral_data;
	
	// Variables to store function results 
	int16_t result;
	LPSTR scpi_result;
	
	// Connect to device
	result = wsaConnect(&wsaHandle, ip);
	result = wsaSetSCPI(wsaHandle, "*RST");
	result = wsaSetSCPI(wsaHandle, ":SYSTEM:ABORT");
	scpi_result = wsaGetSCPI(wsaHandle, ":SYSTEM:LOCK:REQUEST? ACQ");
	
	// Retrieve the expected number of samples
	result = wsaGetSweepSize(wsaHandle,
					fstart,
					fstop,
					rbw,
					mode,
					attenuator,
					&sweep_size);

	// Allocate memory for spectral data based on the number of samples
	spectral_data = (float*) malloc( sizeof(float) * sweep_size);

	// Capture spectral data
	result = wsaCaptureSpectrum(wsaHandle,
				fstart,
				fstop,
				rbw,
				mode,
				attenuator,
				spectral_data);

	// Print out the spectral data
	for(uint32_t i = 0; i < sweep_size; i++)
		printf("%0.2f \n", spectral_data[i]);

	// Disconnect from device
	result = wsaDisconnect(wsaHandle);
	system("PAUSE");
	return 0;
}

