// Example Script that demonstrates how to use the peak find function
//

#include "stdafx.h"
#include "WSAInterface.h"

int _tmain(int argc, _TCHAR* argv[])
{
	
	// The device instance
	int64_t wsaHandle;

	// Device settings
	char ip[20] = "10.126.110.123";
	uint64_t fstart = 2350000000;
	uint64_t fstop = 2450000000;
	uint32_t rbw = 1000;
	char mode[20] = "SH";
	int32_t attenuator = 0;
	
	// Variable to account for power offsets (cable loss, known gains, etc)
	float ref_offset = 3;
	
	// Variables to hold peak result
	float peak_power = 0;
	uint64_t peak_freq = 0;

	// Values to store function results
	int16_t result;
	LPSTR scpi_result;
	
	// connect to device and reset device to default settings
	result = wsaConnect(&wsaHandle, ip);
	result = wsaSetSCPI(wsaHandle, "*RST");
	result = wsaSetSCPI(wsaHandle, ":SYSTEM:ABORT");

	// acquire data read
	scpi_result = wsaGetSCPI(wsaHandle, ":SYSTEM:LOCK:REQUEST? ACQ");
	
	// call the peak find function
	result = wsaPeakFind(wsaHandle, 
					fstart, 
					fstop, 
					rbw, 
					mode,
					ref_offset,
					attenuator,
					&peak_freq,
					&peak_power);

	// display the peak power, as well as the frequency location of the peak power
	printf("Peak Frequency %0.2f MHz, Peak Power %0.2f dBm \n", (float) peak_freq / 1000000, peak_power);
		
	result = wsaDisconnect(wsaHandle);
	system("PAUSE");
	return 0;
}

