// Example Script that demonstrates how to read a VRT packet, and compute the FFT
//

#include "stdafx.h"
#include "WSAInterface.h"

int _tmain(int argc, _TCHAR* argv[])
{
	
	// The device instance
	int64_t wsaHandle;

	// variables required for the read
	int16_t i16_data[1024];
	int16_t q16_data[1024];
	int32_t i32_data[1024];
	uint32_t timeout = 5000;
	uint32_t stream_id;
	uint8_t spectral_inversion;
	int32_t samples_per_packet;
	uint32_t timestamp_sec;
	uint64_t timestamp_psec;
	int16_t reference_level;
	int64_t bandwidth;
	int64_t center_frequency;
		
	//initialize buffer to store spectral data after FFT
	float *spectral_data;
	
	// required buffer size for spectral data
	int32_t fft_size;


	// array to store the

	// Device IP
	char ip[20] = "10.126.110.104";

	// Values to store function results
	int16_t result;
	LPSTR scpi_result;
	
	// connect to device and reset device to default settings
	result = wsaConnect(&wsaHandle, ip);

	result = wsaSetSCPI(wsaHandle, "*RST");
	
	// acquire read access
	scpi_result = wsaGetSCPI(wsaHandle, ":SYSTEM:LOCK:REQUEST? ACQ");
	
	// set the input mode to SH
	result = wsaSetSCPI(wsaHandle, "INPUT:MODE SH");
	
	// set the frequency to 2 GHz
	result = wsaSetSCPI(wsaHandle, "FREQ:CENT 2 GHz");
	
	// set the SPP to 1024
	result = wsaSetSCPI(wsaHandle, "TRACE:SPP 1024");
	
	// capture the data
	result = wsaSetSCPI(wsaHandle, ":TRACE:BLOCK:DATA?\n");

	// read the data
	result = wsaReadData(wsaHandle,
								  i16_data, 
								  q16_data,
								  i32_data,
								  timeout,
								  &stream_id,
								  &spectral_inversion,
								  &samples_per_packet,
								  &timestamp_sec,
								  &timestamp_psec,
								  &reference_level,
								  &bandwidth,
								  &center_frequency);


	//determine FFT size required
	fft_size = samples_per_packet / 2;

	// allocate data for the spectral data variable
	spectral_data = (float*) malloc(sizeof(float) * fft_size);

	// compute the FFT
	result = wsaComputeFFT(samples_per_packet,
						fft_size,
						(int32_t) stream_id,
						reference_level,
						spectral_inversion,
						i16_data,
						q16_data,
						i32_data,
						spectral_data);

	// disconnect from device
	result = wsaDisconnect(wsaHandle);

	// print out values
	for (int i = 0; i < (fft_size); i++)
		printf("%d, %0.2f \n", i, spectral_data[i]);
	

	// free FFT buffer
	free(spectral_data);
	return 0;
}

