// readWSAData.cpp : Defines the entry point for the console application.
//


#include "stdafx.h"
extern "C" {
	#include "wsa_api.h"
	#include "wsa_lib.h"
	#include "wsa_error.h"
}
#include <iostream>

int _tmain(int argc, _TCHAR* argv[])
{
	// initialize WSA structure and IP setting
    struct wsa_device wsa_dev;	// the wsa device structure
    struct wsa_device *dev;
	char wsa_addr[255] = "10.126.110.106";	// store wsa ip address
    char intf_str[255];
	sprintf(intf_str, "TCPIP::%s", wsa_addr);
	
	// initialize WSA settings
	int32_t samples_per_packet = 1024; // sample size per packet
	char input_mode[255] = "SH"; // RFE input mode
	int16_t acq_status = 0;
	int32_t array_size = 0;
	
    int16_t result;
    float max_buffer = -200;
	int32_t exit_loop = 0;
	
	// to store different VRT packet types
	struct wsa_vrt_packet_header *header;
	struct wsa_vrt_packet_trailer *trailer;
	struct wsa_receiver_packet *receiver;
	struct wsa_digitizer_packet *digitizer;
	struct wsa_extension_packet *extension;

	// Create buffers to store the decoded I & Q from the raw data
	int16_t *i16_buffer;
	int16_t *q16_buffer;
	int32_t *i32_buffer;
	float *fft_buffer;

	// Allocate header buffer space
	header = (struct wsa_vrt_packet_header *) malloc(sizeof(struct wsa_vrt_packet_header));
	if (header == NULL)
	{
		doutf(DHIGH, "In save_data_to_file: failed to allocate memory for header\n");
		
		return WSA_ERR_MALLOCFAILED;
	}

	// Allocate trailer buffer space
	trailer = (struct wsa_vrt_packet_trailer *) malloc(sizeof(struct wsa_vrt_packet_trailer));
	if (trailer == NULL)
	{
		doutf(DHIGH, "In save_data_to_file: failed to allocate memory for trailer\n");
		free(header);
		
		return WSA_ERR_MALLOCFAILED;
	}

	// allocate receiver packet buffer space
	receiver = (struct wsa_receiver_packet *) malloc(sizeof(struct wsa_receiver_packet));
	if (receiver == NULL)
	{
		doutf(DHIGH, "In save_data_to_file: failed to allocate memory for receiver\n");
		free(header);
		free(trailer);
		
		return WSA_ERR_MALLOCFAILED;
	}

	// allocate digitizer packet buffer space
	digitizer = (struct wsa_digitizer_packet *) malloc(sizeof(struct wsa_digitizer_packet));
	if (digitizer == NULL)
	{
		doutf(DHIGH, "In save_data_to_file: failed to allocate memory for digitizer\n");
		free(header);
		free(trailer);
		free(receiver);
		
		return WSA_ERR_MALLOCFAILED;
	}

	// allocate extension packet buffer space
	extension = (struct wsa_extension_packet *) malloc(sizeof(struct wsa_extension_packet));
	if (extension == NULL)
	{
		doutf(DHIGH, "In save_data_to_file: failed to allocate memory for sweep info struct\n");
		free(header);
		free(trailer);
		free(receiver);
		free(digitizer);
		
		return WSA_ERR_MALLOCFAILED;
	}

	// Allocate i buffer space
	i16_buffer = (int16_t *) malloc(sizeof(int16_t) * samples_per_packet);
	if (i16_buffer == NULL)
	{
		doutf(DHIGH, "In save_data_to_file: failed to allocate memory for i_buffer\n");
		free(header);
		free(trailer);
		free(receiver);
		free(digitizer);
		free(extension);

		return WSA_ERR_MALLOCFAILED;
	}
	
	// Allocate q buffer space
	q16_buffer = (int16_t *) malloc(sizeof(int16_t) * samples_per_packet);
	if (q16_buffer == NULL)
	{
		doutf(DHIGH, "In save_data_to_file: failed to allocate memory for q_buffer\n");
		free(header);
		free(trailer);
		free(receiver);
		free(digitizer);
		free(extension);
		free(i16_buffer);

		return WSA_ERR_MALLOCFAILED;
	}

	// Allocate 32-bit i buffer space
	i32_buffer = (int32_t *) malloc(sizeof(int32_t) * samples_per_packet);
	if (i32_buffer == NULL)
	{
		doutf(DHIGH, "In save_data_to_file: failed to allocate memory for q_buffer\n");
		free(header);
		free(trailer);
		free(receiver);
		free(digitizer);
		free(extension);
		free(i16_buffer);
		free(q16_buffer);
		return WSA_ERR_MALLOCFAILED;
	}

	
	printf("Initializing WSA settings... \n");	
	char capture_mode[255];
    dev = &wsa_dev; // create device pointer
    
	// connect to wsa
	result = wsa_open(dev, intf_str); 
	result=  wsa_send_scpi(dev, "*RST");
	// set the samples per packet
	result = wsa_set_samples_per_packet(dev, samples_per_packet); 
	
	// set the packets per block
	result = wsa_set_packets_per_block(dev, 1); 

	result =  wsa_set_rfe_input_mode(dev, "SH");
	// Request WSA read data access
	result = wsa_system_request_acq_access(dev, &acq_status);
	//result = wsa_set_freq_shift(dev, 35000000);
	result = wsa_set_freq(dev, 1000000000);
	result = wsa_set_decimation(dev, 32);

	result = wsa_capture_block(dev);
	// loop through all of the packets until an IF data packet is received
	while (exit_loop != 1)
	{
		
		result = wsa_read_vrt_packet(dev, header, trailer, receiver, digitizer,
					extension, i16_buffer, q16_buffer, i32_buffer, samples_per_packet, 5000);

		if (result < 0)
			break;
		
		// handle extension packets
		if (header->packet_type != IF_PACKET_TYPE)
			continue;

		// handle if packet types
		else if (header->packet_type == IF_PACKET_TYPE)
			exit_loop = TRUE;


	} // end save data while loop

	result = wsa_get_fft_size(samples_per_packet, header->stream_id, &array_size);
	fft_buffer = (float *) malloc(sizeof(float) * array_size);
	result = wsa_compute_fft(samples_per_packet,
						array_size,
						header->stream_id,
						digitizer->reference_level,
						trailer->spectral_inversion_indicator,
						i16_buffer,
						q16_buffer,
						i32_buffer,
						fft_buffer);
	for (int i = 0; i < array_size; i++) {
		if (max_buffer < fft_buffer[i] && i > 5){
			max_buffer = fft_buffer[i];
			printf("%0.2f, i: %d \n", fft_buffer[i], i);
		}
	}
	printf("finished reading data \n");
	printf("Center Frequency: %0.3f Hz\n", receiver->freq);
	printf("Bandwidth: %0.3f Hz\n", digitizer->bandwidth);
	printf("Power Peak: %0.2f dBm\n", max_buffer);
	system("PAUSE");
	
	// free all of the buffers
	free(header);
	free(trailer);
	free(receiver);
	free(digitizer);
	free(extension);
	free(i16_buffer);
	free(q16_buffer);
	free(i32_buffer);
}