%% clear matlab memory
clc
clear

%% Set up path.
[mFilePath, ~, ~] = fileparts(mfilename('fullpath'));
addpath(fullfile(mFilePath, '../', 'signal-processing-implementation'));
addpath(fullfile(mFilePath, '..\..', 'wsa-matlab-api'));
buildWsaMex();

%% Set up constants
headerPacketType = 0;

% Make sure this IP address points to your WSA device
ip = '10.126.110.102';

% wsa settings
M = 1000000;
frequency = 2450 * M;
rfeMode = 'SH';
samplesPerPacket = 1024;
packetsPerBlock = 20;
timeOut = 6000;

% define the hanning window
hannWindow = createHannWindow(samplesPerPacket);

%% Connect to WSA
disp('Creating handle WSA...');
wsaHandle = wsaInterface;

disp(['Connecting to IP ', ip]);
[connectionResult errorMessage] = wsaHandle.connect(ip);
if connectionResult >= 0
   disp('Connected successfully');
else
    disp(['Connection error: ' errorMessage ' (Error ID: ' num2str(connectionResult) ')']);
    return
end

% select frequency
[~, errorMessage] = wsaHandle.setFrequency(int64(frequency));

% select sample size
[~, errorMessage] = wsaHandle.setSamplesPerPacket(samplesPerPacket);

% select number of packets
[wsaResult errorMessage] = wsaHandle.setPacketsPerBlock(packetsPerBlock);

% select rfe mode of operation 
[errorCode errorMessage ] = wsaHandle.setRfeMode(rfeMode);

%% Obtain read access
wsaHandle.getReadDataAccess();

total_data = [];
% capture a block of data
wsaHandle.captureBlock();
for n = 1:packetsPerBlock
    
    [header digitizer receiver extension data trailer] = readWSAVRT(wsaHandle, samplesPerPacket, timeOut);
    total_data = cat(1, total_data, data);
end

%% Process data here
[noiseLevel noiseLevelOffset] = getNoiseFloor(digitizer.referenceLevel);
iData = double(data);
qData = iData;

% subplot(2,1,qMod)
% uncomment the line below to print all IQ samples to the screen
% disp(data);

% uncomment this line to display fft
% disp(fftResult)

%% Done processing
disp('Closing connection...');
clear wsaHandle;