%% clear matlab memory
clc
clear

%% Set up path.
[mFilePath, ~, ~] = fileparts(mfilename('fullpath'));
addpath(fullfile(mFilePath, '../', 'signal-processing-implementation'));
addpath(fullfile(mFilePath, '../../', 'wsa-matlab-api'));
buildWsaMex();

%% Set up constants
headerPacketType = 0;

% Make sure this IP address points to your WSA device
ip = '10.126.110.113';

% wsa settings
M = 1000000;
frequency = 100 * M;
rfeMode = 'HDR';
samplesPerPacket = 4096;
packetsPerBlock = 1;
hdrGain = 25;
pllReference = 'EXT'

% define the hanning window
hannWindow = createHannWindow(samplesPerPacket);

%% Connect to WSA
disp('Creating handle WSA...');
wsaHandle = wsaInterface;

disp(['Connecting to IP ', ip]);
[connectionResult errorMessage] = wsaHandle.connect(ip);
if connectionResult >= 0
   disp('Connected successfully');
else
    disp(['Connection error: ' errorMessage ' (Error ID: ' num2str(connectionResult) ')']);
    return
end

% select frequency
[~, errorMessage] = wsaHandle.setFrequency(int64(frequency));

% set attenuator
[~, errorMessage] = wsaHandle.setAttenuator(0);

% select sample size
[~, errorMessage] = wsaHandle.setSamplesPerPacket(samplesPerPacket);

% select number of packets
[wsaResult errorMessage] = wsaHandle.setPacketsPerBlock(packetsPerBlock);

% select rfe mode of operation 
[errorCode errorMessage ] = wsaHandle.setRfeMode(rfeMode);


% set pll reference mode of operation 
[errorCode errorMessage ] = wsaHandle.setRefPll(pllReference);

% set pll reference mode of operation 
[errorCode errorMessage ] = wsaHandle.sendSCPICommand('INPUT:GAIN:HDR 25 dB');

%% Obtain read access
wsaHandle.getReadDataAccess();

% capture a block of data
wsaHandle.captureBlock();
[header digitizer receiver extension data trailer] = readWSAVRT(wsaHandle, samplesPerPacket);
digitizer.referenceLevel

Idata = double(data) / 8388608;


fftResult = calculateFftVeryLowBand(Idata, double(digitizer.referenceLevel), hannWindow, samplesPerPacket);

plot(fftResult)


% subplot(2,1,qMod)
% uncomment the line below to print all IQ samples to the screen
% disp(data);

% uncomment this line to display fft
% disp(fftResult)

%% Done processing
disp('Closing connection...');
clear wsaHandle;