%% clear matlab memory
clc
clear

%% Set up path.

[mFilePath, ~, ~] = fileparts(mfilename('fullpath'));
addpath(fullfile(mFilePath, '..\..', 'wsa-matlab-api'));
addpath(fullfile(mFilePath, '../', 'signal-processing-implementation'));
buildWsaMex();

%% Set up constants
headerPacketType = 0;

% Make sure this IP address points to your WSA device
ip = '10.126.110.110';

% wsa settings
M = 1000000;
frequency = 2110 * M;
rfeMode = 'SHN';
decimation = 8;
samplesPerPacket = 1024;
packetsPerBlock = 1;

% define the hanning window
hannWindow = createHannWindow(samplesPerPacket);

%% Connect to WSA
disp('Creating handle WSA...');
wsaHandle = wsaInterface;

disp(['Connecting to IP ', ip]);
[connectionResult errorMessage] = wsaHandle.connect(ip);
if connectionResult >= 0
   disp('Connected successfully');
else
    disp(['Connection error: ' errorMessage ' (Error ID: ' num2str(connectionResult) ')']);
    return
end

% select frequency
[~, errorMessage] = wsaHandle.setFrequency(int64(frequency));

% set attenuator
[~, errorMessage] = wsaHandle.setAttenuator(0);

% select sample size
[~, errorMessage] = wsaHandle.setSamplesPerPacket(samplesPerPacket);

% select number of packets
[wsaResult errorMessage] = wsaHandle.setPacketsPerBlock(packetsPerBlock);

% select rfe mode of operation 
[errorCode errorMessage ] = wsaHandle.setRfeMode(rfeMode);

% set the decimation rate
[errorCode errorMessage ] = wsaHandle.setDecimation(decimation);

%% Obtain read access
wsaHandle.getReadDataAccess();

% capture a block of data
wsaHandle.captureBlock();
[header digitizer receiver extension data trailer] = readWSAVRT(wsaHandle, samplesPerPacket);


%% Process data here
[noiseLevel noiseLevelOffset] = getNoiseFloor(digitizer.referenceLevel);

iData = double(data(1 : samplesPerPacket, 1));
qData = double(data(1 : samplesPerPacket, 2));

fftResult = calculateFft(iData, qData, double(noiseLevelOffset), hannWindow, samplesPerPacket);

plot(fftResult)


% subplot(2,1,qMod)
% uncomment the line below to print all IQ samples to the screen
% disp(data);

% uncomment this line to display fft
% disp(fftResult)

%% Done processing
disp('Closing connection...');
clear wsaHandle;