function plotDataUntilStopped(handles, wsaHandle, hannWindow)

    %% initialize variables
    samplesPerFrame = getappdata(handles.figure1, 'samplesPerFrame');
    framesPerCapture = getappdata(handles.figure1, 'framesPerCapture');
    frequencyContextIndicator = getappdata(handles.figure1, 'frequencyContextIndicator');
    gainContextIndicator = getappdata(handles.figure1, 'gainContextIndicator');
    referenceLeverlIndicator = getappdata(handles.figure1, 'referenceLevelIndicator');
    blockCaptureMode = getappdata(handles.figure1, 'blockCaptureMode');
    dataPacketType = getappdata(handles.figure1, 'dataPacketType');
    contextPacketType = getappdata(handles.figure1, 'contextPacketType');
    packetType = dataPacketType;
    timeOut = 6000;
    
   %% attempts to obtain read access from the wsa
   [output , ~, accessStatus] = wsaHandle.getReadDataAccess();
    if ((accessStatus == false) || (output < 0))
        displayErrorMessage('WSA read access denied');
        setGuiState('frozen', handles);
        set(handles.startButton, 'userData', 0);
        setGuiState('connected', handles);
    end

    %% continuously read data
    try
        while (ishandle(handles.startButton) && get(handles.startButton, 'userData'))
            
            [errorCode errorMessage] = wsaHandle.captureBlock();
            [header digitizer receiver extension data trailer] = readWSAVRT(wsaHandle, samplesPerFrame * framesPerCapture, timeOut);
            %% process data packet

            if (any(any(data)) && (header.packetType == dataPacketType))
                startIndex = 1;
                endIndex = samplesPerFrame;
                
                % determine the noise level offset
                [noiseLevel noiseLevelOffset] = getNoiseFloor(double(digitizer.referenceLevel));
                %% average data if needed
                
                if get(handles.averageCheckbox, 'Value') == get(handles.averageCheckbox, 'Min');
					% Plotting each frame
					for i = 1 : framesPerCapture

                        iData = double(data(startIndex : endIndex, 1))./8192;
						qData = double(data(startIndex : endIndex, 2))./8192;
                        
                           
                        % process the raw I and Q data and produce the power spectrum
                        powData = doFftProcessing(handles, iData, qData, noiseLevelOffset, hannWindow, samplesPerFrame);
						powHistoryDataToPlot = updateFFTHistory(handles, powData);
						
                        handles.updatePlots(handles,  iData, qData, powData, powHistoryDataToPlot);
						startIndex = startIndex + samplesPerFrame;
						endIndex = endIndex + samplesPerFrame;
					end
                else
                    % Plotting the average of all frames
                    iDataSum = zeros(samplesPerFrame, 1);
                    qDataSum = zeros(samplesPerFrame, 1);


                    powSum = zeros(samplesPerFrame, 1);


                    for i = 1 : framesPerCapture

                        iData = double(data(startIndex : endIndex, 1))./8192;
                        qData = double(data(startIndex : endIndex, 2))./8192;
  
                        iDataSum = iDataSum + qData;
                        qDataSum = qDataSum + iData;

                        powData = doFftProcessing(handles, iData, qData, noiseLevelOffset, hannWindow, samplesPerFrame);
                        powSum = powSum + powData;

                        startIndex = startIndex + samplesPerFrame;
                        endIndex = endIndex + samplesPerFrame;
                    end

                    iDataAverage = iDataSum ./ framesPerCapture;
                    qDataAverage = qDataSum ./ framesPerCapture;
                    powAverage = powSum ./ framesPerCapture;
                    powHistoryDataToPlot = updateFFTHistory(handles, powAverage);
                    handles.updatePlots(handles, iDataAverage, qDataAverage, powAverage, powHistoryDataToPlot);
                
                end
                
            end
            
        end

    catch exception
        rethrow(exception);
    
    end
end


function [powData] = doFftProcessing(handles, iData, qData, noiseLevelOffset, hannWindow, samplesPerFrame)
        powData = calculateFft(iData, qData, noiseLevelOffset, hannWindow, samplesPerFrame);
end
